@@ -4,9 +4,12 @@
 import logging
 from collections import defaultdict
 
+from octopus.limiter import Limiter as BaseLimiter
 
-class Limiter(object):
+
+class Limiter(BaseLimiter):
     def __init__(self, *domains):
+        super(Limiter, self).__init__()
         self.domains = domains
         self.domain_count = defaultdict(int)
 
@@ -28,7 +31,8 @@ class Limiter(object):
         domain = self.get_domain_from_url(url)
         if domain is None:
             logging.info('Tried to acquire lock to a domain that was not specified in the limiter (%s).' % url)
-            return True
+            self.publish_lock_miss(url)
+            return False
 
         limit = self.get_domain_limit(url)
 
@@ -36,6 +40,7 @@ class Limiter(object):
             self.domain_count[domain] += 1
             return True
 
+        self.publish_lock_miss(url)
         return False
 
     def release(self, url):
